// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package openim

import (
	"context"
	"fmt"
	"github.com/tidwall/gjson"
	"time"

	"property-thirdparty/errors"
	"property-thirdparty/parser"
	pb_v1 "property-thirdparty/pb/v1"
	"property-thirdparty/thirdparty"

	"encoding/json"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func OpenImUserSetFace(ctx context.Context, req *pb_v1.OpenImUserSetFaceRequest) (reply *pb_v1.OpenImUserSetFaceReply, err error) {
	reply = &pb_v1.OpenImUserSetFaceReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.OpenimId == "" || req.PlatformId == 0 || req.FaceUrl == "" {
		return nil, errors.ParamsError
	}
	token, _, err := openImTokenByUser(req.PlatformId, req.OpenimId)
	if err != nil {
		return nil, err
	}
	pdata := map[string]interface{}{
		"faceURL":     req.FaceUrl,
		"operationID": fmt.Sprintf("%d%s", time.Now().Unix(), req.OpenimId),
		"userID":      req.OpenimId,
	}
	pbytes, _ := json.Marshal(pdata)

	hreq := thirdparty.HttpRequestWithHead{
		Url:    parser.Conf.ThirdParty.OpenIm.SetFaceUrl,
		Head:   map[string]string{"Content-Type": "application/json", "token": token},
		Body:   pbytes,
		Method: "POST",
	}

	rbytes, err := hreq.Request()
	if err != nil {
		return nil, err
	}
	code := gjson.GetBytes(rbytes, "errCode").Int()
	if code != 0 {
		msg := gjson.GetBytes(rbytes, "errMsg").String()
		logger.Error("thirdparty",
			zap.String("call", "OpenImSetFace"),
			zap.String("error", msg))
		return reply, errors.VendorError
	}

	return reply, nil

}
