// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package tencent_msg

import (
	"context"
	"time"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/logger"
	"github.com/tidwall/gjson"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-thirdparty/errors"
	"property-thirdparty/parser"
	pb_v1 "property-thirdparty/pb/v1"
	"property-thirdparty/thirdparty"
)

// 腾讯云短信消息发送
func RobotMsg(ctx context.Context, req *pb_v1.RobotMsgRequest) (reply *pb_v1.RobotMsgReply, err error) {
	reply = &pb_v1.RobotMsgReply{}
	initMsgType()
	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	body := map[string]interface{}{
		"msgtype": "text",
		"text":    map[string]interface{}{"content": req.Content},
	}
	bytes, _ := json.Marshal(body)

	h := thirdparty.HttpRequestWithHead{
		Method:  "POST",
		Url:     parser.Conf.ThirdParty.Wx.RobotUrl,
		Body:    bytes,
		TimeOut: 10*time.Second,
	}
	bytes, err = h.Request()
	if err != nil {
		logger.Error("func",
			zap.String("call", "RobotMsg"),
			zap.String("params", req.Content),
			zap.String("error", err.Error()))
		return reply, errors.VendorError
	}
	errcode := gjson.GetBytes(bytes, "errcode").Int()
	errmsg := gjson.GetBytes(bytes, "errmsg").String()
	if errcode != 0 {
		logger.Error("func",
			zap.String("call", "RobotMsg"),
			zap.String("params", req.Content),
			zap.String("error", errmsg))
		return reply, errors.VendorError
	}
	return reply, nil

}
