// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package wxapplet

import (
	"context"
	"fmt"
	"github.com/go-pay/gopay/wechat"
	"property-thirdparty/errors"
	"property-thirdparty/parser"
	pb_v1 "property-thirdparty/pb/v1"
	"git.getensh.com/common/gopkgs/logger"

	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	json2 "encoding/json"
)

type JsonStruct struct {

}
func (p *JsonStruct)MarshalToString(v interface{}) (string, error) {
	bytes, err := json2.Marshal(v)
	return string(bytes), err
}
func (p *JsonStruct)Marshal(v interface{}) ([]byte, error) {
	bytes, err := json2.Marshal(v)
	return bytes, err
}
func (p *JsonStruct)Unmarshal(bytes []byte, v interface{}) (error) {
	err := json2.Unmarshal(bytes, v)
	return err
}
var json = &JsonStruct{}


// 微信小程序登录验证
func WxAppletLoginAuth(ctx context.Context, req *pb_v1.WxAppletLoginAuthRequest) (reply *pb_v1.WxAppletLoginAuthReply, err error) {
	reply = &pb_v1.WxAppletLoginAuthReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.Code == "" {
		return nil, errors.ParamsError
	}
	resp, err := wechat.Code2Session(parser.Conf.ThirdParty.Wx.AppletAppId, parser.Conf.ThirdParty.Wx.AppletAppSecret, req.Code)

	if err != nil {
		logger.Error("func",
			zap.String("call", "wechat.Code2Session"),
			zap.String("params", req.Code),
			zap.String("error", err.Error()))
		return nil, status.Error(10006, "三方错误:微信小程序登录验证失败")
	}
	reply.OpenId = resp.Openid
	reply.SessionKey = resp.SessionKey
	reply.UnionId = resp.Unionid

	return reply, nil
}
