package wxapplet

import (
	"github.com/go-pay/gopay/wechat"
	"fmt"
	gerrors "errors"
	"go.uber.org/zap"
	"property-thirdparty/errors"
	pb_v1 "property-thirdparty/pb/v1"
	"context"
	"git.getensh.com/common/gopkgs/logger"
	"google.golang.org/grpc/status"
)



func getPublicUnionId(accessToken string, openId string) (string, error) {
	if accessToken == "" || openId == "" {
		return "", gerrors.New("access token 或 openid 为空")
	}
	userInfo, err := wechat.GetPublicUserInfo(accessToken, openId, "zh_CN")
	if err != nil {
		return "", err
	}
	bytes, _ := json.Marshal(userInfo)
	fmt.Printf("userinfo:%s\n", bytes)
	if userInfo.Errmsg != "" {
		return "", gerrors.New(fmt.Sprintf("%v %v", userInfo.Errcode, userInfo.Errmsg))
	}
	return userInfo.Unionid, nil
}


func WxPublicUnionId(ctx context.Context, req *pb_v1.WxPublicUnionIdRequest) (reply *pb_v1.WxPublicUnionIdReply, err error) {
	reply = &pb_v1.WxPublicUnionIdReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.OpenId == "" {
		return nil, errors.ParamsError
	}
	accessToken, err := GetPublicAccessToken()
	if err != nil {
		logger.Error("func",
			zap.String("call", "GetPublicAccessToken"),
			zap.String("error", err.Error()))
		return nil, errors.VendorError
	}

	unionId, err := getPublicUnionId(accessToken, req.OpenId)
	if err != nil {
		logger.Error("func",
			zap.String("call", "getPublicUnionId"),
			zap.String("param", req.OpenId),
			zap.String("error", err.Error()))
		return nil, errors.VendorError
	}
	reply.UnionId = unionId

	return reply, nil
}

func GetUnionIdTest() {
	mreq := pb_v1.WxPublicUnionIdRequest{OpenId:"o4o5D6khn-6n19rSAiEz9CJyM0vo"}
	mreply, err := WxPublicUnionId(context.Background(), &mreq)
	fmt.Printf("%v,%v\n", mreply, err)
}